###Sphinx reload

installare il pacchetto ```sphinx-reload``` nell'ambiente virtuale o globalmente e lanciare il comando
```
sphinx-reload $DIR
```
dove ```$DIR``` è la cartella principale delal documentazione 